@@ -14,6 +14,62 @@ from squarelet_auth import settings
 logger = logging.getLogger(__name__)
 
 
+class Membership(models.Model):
+    """Through table for organization membership"""
+
+    user = models.ForeignKey(
+        verbose_name=_("user"),
+        to=settings.AUTH_USER_MODEL,
+        on_delete=models.CASCADE,
+        related_name="memberships",
+        help_text=_("A user being linked to an organization"),
+    )
+    organization = models.ForeignKey(
+        verbose_name=_("organization"),
+        to=settings.ORGANIZATION_MODEL,
+        on_delete=models.CASCADE,
+        related_name="memberships",
+        help_text=_("An organization being linked to a user"),
+    )
+    active = models.BooleanField(
+        _("active"),
+        default=False,
+        help_text=_("The user is currently working on behalf of this organization"),
+    )
+    admin = models.BooleanField(
+        _("admin"),
+        default=False,
+        help_text=_("The user is an administrator for this organization"),
+    )
+
+    class Meta:
+        unique_together = ("user", "organization")
+
+    def __str__(self):
+        return f"{self.user} in {self.organization}"
+
+
+class Entitlement(models.Model):
+    """Entitlements granted to organizations through plans"""
+
+    name = models.CharField(_("name"), max_length=255, unique=True)
+    slug = models.SlugField(_("slug"), max_length=255, unique=True)
+    description = models.TextField()
+    resources = JSONField(default=dict)
+
+    def __str__(self):
+        return self.name
+
+
+# dynamically create properties for all defined resource fields
+for field_, default in settings.RESOURCE_FIELDS.items():
+    setattr(
+        Entitlement,
+        field_,
+        property(lambda self, f=field_, d=default: self.resources.get(f, d)),
+    )
+
+
 class AbstractOrganization(models.Model):
     """An orginization users can belong to"""
 
@@ -29,7 +85,7 @@ class AbstractOrganization(models.Model):
     users = models.ManyToManyField(
         verbose_name=_("users"),
         to=settings.AUTH_USER_MODEL,
-        through="squarelet_auth_organizations.Membership",
+        through=Membership,
         related_name="organizations",
         help_text=_("The users who are members of this organization"),
     )
@@ -57,7 +113,7 @@ class AbstractOrganization(models.Model):
     )
     entitlement = models.ForeignKey(
         verbose_name=_("entitlement"),
-        to="squarelet_auth_organizations.Entitlement",
+        to=Entitlement,
         on_delete=models.PROTECT,
         null=True,
         help_text=_("The subscription type for this organization"),
@@ -156,7 +212,7 @@ class AbstractOrganization(models.Model):
             )
             date_update = None
 
-        self._update_resources(data)
+        self._update_resources(data, date_update)
 
         # update the remaining fields
         fields = [
@@ -164,7 +220,6 @@ class AbstractOrganization(models.Model):
             "slug",
             "individual",
             "private",
-            "date_update",
             "card",
             "payment_failed",
             "avatar_url",
@@ -175,7 +230,7 @@ class AbstractOrganization(models.Model):
                 setattr(self, field, data[field])
         self.save()
 
-    def _update_resources(self, data):
+    def _update_resources(self, data, date_update):
         """Allows subclasses to override to update their resources"""
 
     def _choose_entitlement(self, entitlements):
@@ -188,72 +243,3 @@ class AbstractOrganization(models.Model):
 class Organization(AbstractOrganization):
     class Meta:
         swappable = "SQUARELET_ORGANIZATION_MODEL"
-
-
-class Membership(models.Model):
-    """Through table for organization membership"""
-
-    user = models.ForeignKey(
-        verbose_name=_("user"),
-        to=settings.AUTH_USER_MODEL,
-        on_delete=models.CASCADE,
-        related_name="memberships",
-        help_text=_("A user being linked to an organization"),
-    )
-    organization = models.ForeignKey(
-        verbose_name=_("organization"),
-        to=settings.ORGANIZATION_MODEL,
-        on_delete=models.CASCADE,
-        related_name="memberships",
-        help_text=_("An organization being linked to a user"),
-    )
-    active = models.BooleanField(
-        _("active"),
-        default=False,
-        help_text=_("The user is currently working on behalf of this organization"),
-    )
-    admin = models.BooleanField(
-        _("admin"),
-        default=False,
-        help_text=_("The user is an administrator for this organization"),
-    )
-
-    class Meta:
-        unique_together = ("user", "organization")
-
-    def __str__(self):
-        return f"{self.user} in {self.organization}"
-
-
-class Plan(models.Model):
-    """Plans that organizations can subscribe to
-    DEPRECATED: not removed as it breaks migrations
-    """
-
-    name = models.CharField(_("name"), max_length=255, unique=True)
-    slug = models.SlugField(_("slug"), max_length=255, unique=True)
-    resources = JSONField(default=dict)
-
-    def __str__(self):
-        return self.name
-
-
-class Entitlement(models.Model):
-    """Entitlements granted to organizations through plans"""
-
-    name = models.CharField(_("name"), max_length=255, unique=True)
-    slug = models.SlugField(_("slug"), max_length=255, unique=True)
-    description = models.TextField()
-    resources = JSONField(default=dict)
-
-    def __str__(self):
-        return self.name
-
-
-# dynamically create properties for all defined resource fields
-for field, default in settings.RESOURCE_FIELDS.items():
-    setattr(
-        Entitlement,
-        field,
-        property(lambda self, f=field, d=default: self.resources.get(f, d)),
-    )
