@@ -1,4 +1,5 @@
 # Django
+from django.conf import settings
 from django.contrib import messages
 from django.contrib.auth.decorators import login_required
 from django.shortcuts import redirect
@@ -14,7 +15,7 @@ Organization = get_organization_model()
 def activate(request):
     """Activate one of your organizations"""
     redirect_url = request.POST.get("next", "/")
-    redirect_url = redirect_url if is_safe_url(redirect_url) else "/"
+    redirect_url = redirect_url if is_safe_url(redirect_url, allowed_hosts=[]) else "/"
 
     try:
         organization = request.user.organizations.get(
@@ -33,3 +34,7 @@ def activate(request):
         messages.error(request, "You are not a member of that organization")
 
     return redirect(redirect_url)
+
+
+def profile(request, slug):
+    return redirect(f"{settings.SQUARELET_URL}/organizations/{slug}/")
